@@ -31,30 +31,15 @@ class FrameworkDropRowsWithNullTransformer(FrameworkTransformer):
         super().__init__()
         self.logger = get_logger(__name__)
 
-        self.view: Param = Param(self, "view", "")
+        self.view: Param[str] = Param(self, "view", "")
         self._setDefault(view=view)
 
-        self.columns_to_check: Param = Param(self, "columns_to_check", "")
+        self.columns_to_check: Param[List[str]] = Param(self, "columns_to_check", "")
         self._setDefault(columns_to_check=columns_to_check)
 
         kwargs = self._input_kwargs
         self.setParams(**kwargs)
 
-    @keyword_only
-    def setParams(
-        self,
-        view: str,
-        columns_to_check: List[str],
-        name: Optional[str] = None,
-        parameters: Optional[Dict[str, Any]] = None,
-        progress_logger: Optional[ProgressLogger] = None,
-    ) -> Any:
-        kwargs = self._input_kwargs
-        super().setParams(
-            name=name, parameters=parameters, progress_logger=progress_logger
-        )
-        return self._set(**kwargs)
-
     def _transform(self, df: DataFrame) -> DataFrame:
         columns_to_drop: List[str] = self.getColumnsToCheck()
         view: str = self.getView()
@@ -67,14 +52,15 @@ class FrameworkDropRowsWithNullTransformer(FrameworkTransformer):
                 f"dropping rows if any null values found for columns: {columns_to_drop}"
             )
             df_with_rows: DataFrame = df.sql_ctx.table(view)
+            df.sql_ctx.dropTempTable(view)
             df_with_dropped_rows = df_with_rows.dropna(subset=columns_to_drop)
             df_with_dropped_rows.createOrReplaceTempView(view)
         return df
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getView(self) -> str:
-        return self.getOrDefault(self.view)  # type: ignore
+        return self.getOrDefault(self.view)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getColumnsToCheck(self) -> List[str]:
-        return self.getOrDefault(self.columns_to_check)  # type: ignore
+        return self.getOrDefault(self.columns_to_check)
